from __future__ import division
import numpy as np
import matplotlib.pyplot as plt
import analysis

n_neurons = 2048 # number of excitatory neurons
t_window = (4.25, 4.5) # time window for firing rate profiles (s)
n_smooth = 20 # neuron window for smoothing

### Load spike rasters and make firing rate profiles ###
path = 'sim_code/'
filename_control ='spikes_e_control.dat'
filename_disinhib = 'spikes_e_disinhib.dat'

spikes_e_control = analysis.load_raster(path+filename_control)
r = analysis.spike_count_onebin(spikes_e_control[:,0],spikes_e_control[:,1],\
                                n_neurons,t_window)/(t_window[1]-t_window[0])
rs_control = analysis.sliding_win_on_circ_data(r,n_smooth)

spikes_e_disinhib = analysis.load_raster(path+filename_disinhib)
r = analysis.spike_count_onebin(spikes_e_disinhib[:,0],spikes_e_disinhib[:,1],\
                                n_neurons,t_window)/(t_window[1]-t_window[0])
rs_disinhib = analysis.sliding_win_on_circ_data(r,n_smooth)


### Make figure ###
fig = plt.figure(figsize=(8,10.5))
n_skip=8 # sparsen scatter plots

### Spike rastergram for control condition ###
ax1 = fig.add_subplot(311)
ax1.scatter(spikes_e_control[:,1][::n_skip],360/n_neurons*spikes_e_control[:,0][::n_skip],\
            marker='.',c='blue',edgecolor='none',alpha=0.5)
ax1.set_ylim(0,360)
ax1.set_xlim(0,4.5)
ax1.set_yticks(np.linspace(0,360,7))
ax1.set_ylabel('Neuron label (deg)')
ax1.set_xlabel('Time (s)')

### Spike rastergram for disinhibition condition ###
ax2 = fig.add_subplot(312)
ax2.scatter(spikes_e_disinhib[:,1][::n_skip],360/n_neurons*spikes_e_disinhib[:,0][::n_skip],\
            marker='.',c='orange',edgecolor='none',alpha=0.5)
ax2.set_ylim(0,360)
ax2.set_xlim(0,4.5)
ax2.set_yticks(np.linspace(0,360,7))
ax2.set_ylabel('Neuron label (deg)')
ax2.set_xlabel('Time (s)')

### Firing rate profiles for both conditions ###
ax3 = fig.add_subplot(313)
theta = np.linspace(0,360,2048,endpoint=False)
ax3.plot(theta,rs_control,c='blue',lw=2,label='Control')
ax3.plot(theta,rs_disinhib,c='orange',lw=2,label='Disinhibition')
ax3.set_xlabel('Neuron label (deg)')
ax3.set_ylabel('Firing rate (Hz)')
ax3.set_xlim(0,360)
ax3.set_xticks(np.linspace(0,360,9))
ax3.set_ylim(0,)
ax3.legend(frameon=False    )

# Save figure
fig.savefig('murray2014_example.pdf')