# size of the network
NE          = 2048          # number of E cells
NI          = 512           # number of I cell

# simulation-related parameters
simtime     = 4500*ms       # total simulation time [ms]
dt          = 0.02*ms     	# simulation step length [ms]
simulation_clock=Clock(dt=dt)   # clock for the time steps

# pyramidal cells
Cm_e        = 0.5*nF  		# [nF] total capacitance
gl_e        = 25.0*nS 		# [ns] total leak conductance
El_e        = -70.0*mV		# [mV] leak reversal potential
Vth_e       = -50.0*mV		# [mV] threshold potential
Vr_e	    = -60.0*mV		# [mV] resting potential
tr_e	    = 2.0*ms		# [ms] refractory time

# interneuron cells
Cm_i        = 0.2*nF		# [nF] total capacitance
gl_i        = 20.0*nS		# [ns] total leak conductance
El_i        = -70.0*mV 		# [mV] leak reversal potential
Vth_i       = -50.0*mV 		# [mV] threshold potential
Vr_i	    = -60.0*mV 		# [mV] resting potential
tr_i	    = 1.0*ms  		# [ms] refractory time

# external background input
fext_e	    = 600*Hz # [Hz] external input frequency (poisson train)
fext_i      = 600*Hz

# AMPA receptor (APMAR)
E_ampa 	    = 0.0*mV  		# [mV] synaptic reversal potential
t_ampa	    = 2.0*ms  		# [ms] exponential decay time constant
g_ext_e	    = 3.*3.1*nS     # [nS] maximum conductance from external to pyramidal cells
g_ext_i	    = 3.*2.38*nS    # [nS] maximum conductance from external to interneuron cells

# GABA receptor (GABAR)
E_gaba 	    = -70.0*mV	  	# [mV] synaptic reversial potential
t_gaba	    = 10.0*ms		# [ms] exponential decay time constant
Gie	        = 1.18*1.336/(NI/512.)*nS           # [ns] synaptic conductance interneuron to pyramidal cells
Gii	        = 1.08*1.024/(NI/512.)*nS           # [ns] synaptic conductance interneuron to interneuron cells

# NMDA receptor (NMDAR)
E_nmda 	    = 0.0*mV	 	# [mV] synaptic reversial potential
t_nmda      = 100.0*ms		# [ms] decay time of NMDA currents
t_x	        = 2.0*ms		# [ms] controls the rise time of NMDAR channels
alpha        = 0.5*kHz	  	# [kHz] controls the saturation properties of NMDAR channels
a           = 0.062/mV      # [1/mV] control the voltage dependance of NMDAR channel
b           = 1.0/3.57      # [1] control the voltage dependance of NMDAR channel ([Mg2+]=1mM )
Gee_nmda	= 1.07*1.2*.381/(NE/2048.)*nS       # [ns] synaptic conductance from pyramidal to pyramidal cells
Gei_nmda	= 1.2*.292/(NE/2048.)*nS            #[ns] synaptic conductance from pyramidal to interneuron cells

# Connectivity
Jp_ee 	    = 3. # maximum connection weight from pyramidal to pyramidal
sigma_ee    = 9. # width of the connectivity footprint from pyramidal to pyramidal [deg.]

# Stimulus
# cue parameters
tc_start      = 1000*ms             # start of the cue signal
tc_dur        = 250*ms              # length period of the cue signal
i_cue_amp     = 375*pA              # cue current amplitude
i_cue_ang     = 180.                 # mean angle of the cue current
i_cue_width   = 6.                  # sigma/width of the current signal in degrees
dt_curr       = 50*ms               # current_clock step length (should be the highest common denominator between tc_start and tr_stop)


# distractor parameters
tdist_start   = 2750*ms             # start of the cue signal
tdist_dur     = 250*ms              # length period of the cue signal
i_dist_amp    = 0*375*pA              # cue current amplitude
i_dist_ang    = 270.                # mean angle of the cue current
i_dist_width  = 6.                  # sigma/width of the current signal in degrees
dt_curr       = 50*ms               # current_clock step length (should be the highest common denominator between tc_start and tr_stop)

